import getpass
import gettext
import os
import subprocess
import locale


def get_user(from_file=None):
    try:
        user_name = getpass.getuser()
    except Exception:
        user_name = os.getlogin()

    if from_file and os.path.exists(from_file):
        exit_code, candidate = subprocess.getstatusoutput('cat {} | tail -n 1 | cut -f 2 -d "@"'.format(from_file))
        if exit_code != 0:
            user_name = candidate

    if user_name == 'root':
        if 'SUDO_USER' in os.environ and os.environ['SUDO_USER'] != 'root':
            user_name = os.environ['SUDO_USER']
        else:
            user_name = subprocess.getoutput('w -h | head -n 1 | cut -f 1 -d " "')

    return user_name


def get_languages():
    languages = ['en']
    try:
        user_environ = locale.getlocale()[0]
        for lang in ["en", "es", "it", "pt", "gl"]:
            if user_environ.find(lang) >= 0:
                languages = [lang]
                break
    except Exception:
        pass
    return languages


def load_translation(filename):
    current_path = os.path.dirname(os.path.realpath(__file__))
    languages = get_languages()
    return gettext.translation(
        filename,
        os.path.join(current_path, 'translations'),
        languages=languages,
        fallback=True
    ).gettext



#!/usr/bin/python3
# -*- coding: utf-8 -*-

# triggered by .autostrart
import os
import sys
import subprocess
import utils
from configparser import ConfigParser

USER_NAME = utils.get_user()
HOMEDIR = os.path.expanduser("~{}".format(USER_NAME))
CONFIG_FILE = os.path.join(
    HOMEDIR, ".config/slimbookrgbkeyboard/slimbookrgbkeyboard.conf")
print("Configuration file: {}\n".format(CONFIG_FILE))

AUTOSTART_FILE = os.path.join(
    HOMEDIR, ".config/autostart/slimbookrgbkeyboard-autostart.desktop")

config = ConfigParser()
config.read(CONFIG_FILE)




def main(args):
    check_config()
    # Argument 0 is the current route
    if len(args) > 1:
        print("Setting "+args[1]+" ...")

        if args[1] == "cmd":
            cmd = ' '.join(args[2:])
            subprocess.Popen(cmd, shell=True)

        if args[1] == "state":
            state = config.get('CONFIGURATION', 'state')
            if state == "on":
                effect = config.get('CONFIGURATION', 'effect')
                os.system(effect)
            else:
                os.system("sudo ite8291r3-ctl off")

        elif args[1] == "effect":
            effect = config.get('CONFIGURATION', 'effect')
            os.system(effect)

        elif args[1] == "brightness":
            brightness = config.get('CONFIGURATION', 'brightness')
            os.system("sudo ite8291r3-ctl brightness "+brightness)

        elif args[1] == "lb_state":
            lb_state = config.get('CONFIGURATION', 'lb_state')
            print("Aplicando color "+lb_state)
            call = subprocess.getstatusoutput(
                "sudo su -c 'echo "+lb_state+" > /sys/class/leds/qc71_laptop\:\:lightbar/brightness'")
            print("Exit: "+str(call[0]))  # Apply state

        elif args[1] == "lb_rainbow":
            lb_rainbow = config.get('CONFIGURATION', 'lb_rainbow')
            print("Aplicando rainbow "+lb_rainbow)
            call = subprocess.getstatusoutput(
                "sudo su -c 'echo "+lb_rainbow+" > /sys/class/leds/qc71_laptop\:\:lightbar/rainbow_mode'")
            print("Exit: "+str(call[0]))  # Apply rainbow

        elif args[1] == "lb_color":
            lb_color = config.get('CONFIGURATION', 'lb_color')
            print("Aplicando color "+lb_color)
            call = subprocess.getstatusoutput(
                "sudo su -c 'echo "+lb_color+" > /sys/class/leds/qc71_laptop\:\:lightbar/color'")
            print("Exit: "+str(call[0]))  # Apply color

        elif args[1] == "pre":
            print('Suspending ...')
            os.system("sudo ite8291r3-ctl off")  # Turn off keyboard
            call = subprocess.getstatusoutput(
                "sudo su -c 'echo 0 > /sys/class/leds/qc71_laptop\:\:lightbar/brightness'")
            print(str(call))  # Apply

            # We change our variable: config.set(section, variable, value)
            config.set('CONFIGURATION', "suspension", "")

            # Writing our configuration file
            with open(CONFIG_FILE, 'w') as configfile:
                config.write(configfile)

        elif args[1] == "post":

            if config.get('CONFIGURATION', 'state'):

                state = config.get('CONFIGURATION', 'state')
                effect = config.get('CONFIGURATION', 'effect')
                brightness = config.get('CONFIGURATION', 'brightness')
                suspension = config.get('CONFIGURATION', 'suspension')

                lb_state = config.get('CONFIGURATION', 'lb_state')
                lb_rainbow = config.get('CONFIGURATION', 'lb_rainbow')
                lb_color = config.get('CONFIGURATION', 'lb_color')

                # We apply the keyboard config
                if state == "on":
                    print(state)
                    os.system(effect)
                    call = subprocess.getstatusoutput(effect)
                    print("Exit: "+str(call))  # Apply state

                    call = subprocess.getstatusoutput(
                        "sudo ite8291r3-ctl brightness "+brightness)
                    print("Exit: "+str(call))  # Apply state

                else:
                    os.system("sudo ite8291r3-ctl off")

                # We apply the lightbar config
                if lb_state == "1":
                    print("Aplicando cambios lightbar")

                    print("Aplicando color "+lb_state)
                    call = subprocess.getstatusoutput(
                        "sudo su -c 'echo "+lb_state+" > /sys/class/leds/qc71_laptop\:\:lightbar/brightness'")

                    print("Exit: "+str(call))  # Apply state

                    print("Aplicando rainbow "+lb_rainbow)
                    call = subprocess.getstatusoutput(
                        "sudo su -c 'echo "+lb_rainbow+" > /sys/class/leds/qc71_laptop\:\:lightbar/rainbow_mode'")

                    print("Exit: "+str(call))  # Apply state

                    print("Aplicando color "+lb_color)
                    call = subprocess.getstatusoutput(
                        "sudo su -c 'echo "+lb_color+" > /sys/class/leds/qc71_laptop\:\:lightbar/color'")

                    print("Exit: "+str(call))  # Apply state

                else:
                    # Turn off light bar
                    os.system(
                        "echo 0 > /sys/class/leds/qc71_laptop\:\:lightbar/brightness")

    elif config.get('CONFIGURATION', 'state'):

        state = config.get('CONFIGURATION', 'state')
        effect = config.get('CONFIGURATION', 'effect')
        brightness = config.get('CONFIGURATION', 'brightness')
        suspension = config.get('CONFIGURATION', 'suspension')

        lb_state = config.get('CONFIGURATION', 'lb_state')
        lb_rainbow = config.get('CONFIGURATION', 'lb_rainbow')
        lb_color = config.get('CONFIGURATION', 'lb_color')

        # We apply the keyboard config
        if state == "on":
            print(state)
            os.system(effect)
            call = subprocess.getstatusoutput(effect)
            print("Exit: "+str(call))  # Apply state

            call = subprocess.getstatusoutput(
                "sudo ite8291r3-ctl brightness "+brightness)
            print("Exit: "+str(call))  # Apply state

        else:
            os.system("sudo ite8291r3-ctl off")

        # We apply the lightbar config
        if lb_state == "1":
            print("Aplicando cambios lightbar")

            print("Aplicando color "+lb_state)
            call = subprocess.getstatusoutput(
                "sudo su -c 'echo "+lb_state+" > /sys/class/leds/qc71_laptop\:\:lightbar/brightness'")

            print("Exit: "+str(call))  # Apply state

            print("Aplicando rainbow "+lb_rainbow)
            call = subprocess.getstatusoutput(
                "sudo su -c 'echo "+lb_rainbow+" > /sys/class/leds/qc71_laptop\:\:lightbar/rainbow_mode'")

            print("Exit: "+str(call))  # Apply state

            print("Aplicando color "+lb_color)
            call = subprocess.getstatusoutput(
                "sudo su -c 'echo "+lb_color+" > /sys/class/leds/qc71_laptop\:\:lightbar/color'")

            print("Exit: "+str(call))  # Apply state

        else:
            # Turn off light bar
            os.system(
                "echo 0 > /sys/class/leds/qc71_laptop\:\:lightbar/brightness")


def check_config():

    if not os.path.isfile(CONFIG_FILE):
        print("File doesn't exist")
        if os.path.exists(HOMEDIR+'/.config/slimbookrgbkeyboard'):
            print('Directory already exists')
            os.system('sudo -u '+USER_NAME+' touch '+CONFIG_FILE)
            print('Creating file')

            with open(HOMEDIR + '/.config/slimbookrgbkeyboard/slimbookrgbkeyboard.conf', 'w') as conf:
                fichero_conf().write(conf)

            print('File created succesfully!\n')

            print(os.system("cat " + HOMEDIR +
                  "/.config/slimbookrgbkeyboard/slimbookrgbkeyboard.conf"))
        else:
            print("Directory doesen't exist")
            os.system('mkdir '+HOMEDIR+'/.config/slimbookrgbkeyboard')
            os.system('touch '+CONFIG_FILE)
            print('Creating file')

            with open(CONFIG_FILE, 'w') as conf:
                fichero_conf().write(conf)

            print('File created succesfully!\n')

            print(os.system("cat " + CONFIG_FILE))
    
def fichero_conf():
    config_object = ConfigParser()

    config_object["CONFIGURATION"] = {
        "state": "on",
        "effect": "sudo ite8291r3-ctl effect rainbow",
        "brightness": "50",
        "suspension": "",
        "lb_state": "0",
        "lb_rainbow": "0",
        "lb_color": "777"

    }
    return config_object


if __name__ == "__main__":
    # Se obtiene las variables que se le pasa desde el archivo /usr/share/slimbookface/slimbookface
    main(sys.argv)



import slimbook.kbd

from gi.repository import Gdk, Gtk, GdkPixbuf
from os.path import expanduser

import gi
import utils
import os
import subprocess

gi.require_version('Gtk', '3.0')
gi.require_version('Gdk', '3.0')

_ = utils.load_translation('slimbookrgb')

class Grid(Gtk.Grid):

    def __init__(self, *args, **kwargs):
        super(Grid, self).__init__(*args, **kwargs)
        
        self.backlight_red = 0
        self.backlight_green = 0
        self.backlight_blue = 0
        self.brightness = 0
        
        self.read_backlight()
        
        self.switch1 = Gtk.Switch()
        self.switch1.set_halign(Gtk.Align.END)
        self.switch1.set_active(self.get_average_rgb() > 0)

        self.max_brightness = slimbook.kbd.brightness_max(0)
        
        self.scale = Gtk.Scale.new_with_range(
            orientation = Gtk.Orientation.HORIZONTAL,
            min = 0,
            max = self.max_brightness,
            step = 1
        )
        self.scale.connect("button-release-event", self.on_brightness_change)
        self.scale.set_sensitive(self.switch1.get_active())

        self.scale.set_value(self.brightness)
        self.switch1.connect("state-set", self.on_switch_change)
        
        label1 = Gtk.Label(label=_("Light switch"))
        label1.set_halign(Gtk.Align.START)
        label1.set_name('labelw')

        label2 = Gtk.Label(label=_("Brightness"))
        label2.set_halign(Gtk.Align.START)
        label2.set_name('labelw')

        btn_box = Gtk.HBox(spacing=30)

        red_btn = Gtk.Button()
        red_btn.set_name('red')
        red_btn.connect('clicked', self.on_color_change, (1,0,0))
        btn_box.pack_start(red_btn, True, True, 0)

        green_btn = Gtk.Button()
        green_btn.set_name('green')
        green_btn.connect('clicked', self.on_color_change, (0,1,0))
        btn_box.pack_start(green_btn, True, True, 0)

        blue_btn = Gtk.Button()
        blue_btn.set_name('blue')
        blue_btn.connect('clicked', self.on_color_change, (0,0,1))
        btn_box.pack_start(blue_btn, True, True, 0)

        white_btn = Gtk.Button()
        white_btn.set_name('white')
        white_btn.connect('clicked', self.on_color_change, (1,1,1))
        btn_box.pack_start(white_btn, True, True, 0)

        yellow_btn = Gtk.Button()
        yellow_btn.set_name('yellow')
        yellow_btn.connect('clicked', self.on_color_change, (1,1,0))
        btn_box.pack_start(yellow_btn, True, True, 0)

        magenta_btn = Gtk.Button()
        magenta_btn.set_name('magenta')
        magenta_btn.connect('clicked', self.on_color_change, (1,0,1))
        btn_box.pack_start(magenta_btn, True, True, 0)

        custom_lbl = Gtk.Label(label=_("Custom"))
        custom_lbl.set_halign(Gtk.Align.START)
        custom_lbl.set_name('labelw')
        custom_btn = Gtk.ColorButton()
        custom_btn.set_name('custom')
        custom_btn.connect('color-set', self.on_color_set)

        colors_lbl = Gtk.Label(label='Colors')
        colors_lbl.set_name('labelw')
        colors_lbl.set_halign(Gtk.Align.START)
        
        self.sample = Gtk.DrawingArea()
        self.sample.connect('draw', self.on_draw)
        self.sample.set_size_request(-1,32)
        
        self.set_halign(Gtk.Align.CENTER)
        self.attach(label1, 0, 0, 1, 1)
        self.attach(self.switch1, 3, 0, 1, 1)
        self.attach(label2, 0, 1, 1, 1)
        self.attach(self.scale, 2, 1, 2, 1)
        self.attach(custom_lbl, 0, 3, 1, 1)
        self.attach(custom_btn, 1, 3, 1, 1)
        self.attach(colors_lbl, 0, 5, 4, 1)
        self.attach(btn_box, 0, 6, 5, 1)

        self.set_row_spacing(4)
        self.attach(self.sample, 0, 7, 4, 2)

        self.show_all()

    def on_draw(self, widget, ctx):

        
        r = (self.backlight_red) / 0xff
        g = (self.backlight_green) / 0xff
        b = (self.backlight_blue) / 0xff
        
        w = widget.get_allocated_width()
        h = widget.get_allocated_height()
        
        ctx.set_source_rgba (r,g,b,1)
        ctx.rectangle(0,0,w,h)
        ctx.fill()

    def on_color_set(self, colorbutton):
        color = colorbutton.get_rgba()

        self.backlight_red = int(0xff * color.red)
        self.backlight_green = int(0xff * color.green)
        self.backlight_blue = int(0xff * color.blue)

        self.sample.queue_draw()
        self.write_backlight()

    def on_switch_change(self, widget, state):
        self.scale.set_sensitive(state)
        
        if (not state):
            self.brightness = 0
            
            self.write_backlight()
        else:
            self.brightness = self.max_brightness
            
            self.write_backlight()
        
        self.sample.queue_draw()
    
    def on_brightness_change(self, widget, value):
        self.brightness = self.scale.get_value()
        self.sample.queue_draw()
        self.write_backlight()
    
    def on_color_change(self,widget, value):
        r,g,b=value
        
        self.backlight_red = 0xff * r
        self.backlight_green = 0xff * g
        self.backlight_blue = 0xff * b
        
        self.sample.queue_draw()
        self.write_backlight()
    
    def read_backlight(self):
    
        output = subprocess.getoutput('slimbookctl get-kbd-backlight')
        color = int(output,16)
        
        self.backlight_red = (color & 0xff0000) >> 16
        self.backlight_green = (color & 0x00ff00) >> 8
        self.backlight_blue = color & 0x0000ff
        
        output = subprocess.getoutput('slimbookctl get-kbd-brightness')
        self.brightness = int(output,16)
        
    def write_backlight(self):
        br = int(self.brightness)
        r = int(self.backlight_red)
        g = int(self.backlight_green)
        b = int(self.backlight_blue)
        
        value = (r<<16) | (g<<8) | b
        
        subprocess.getoutput('slimbookctl set-kbd-backlight {0:06x}'.format(value))
        subprocess.getoutput('slimbookctl set-kbd-brightness {0:06x}'.format(br))
    
    def get_average_rgb(self):
        return (self.backlight_red + self.backlight_green + self.backlight_blue) / 3.0




#!/usr/bin/python3
# -*- coding: utf-8 -*-

import slimbook
import slimbook.info

import gi
import utils
import os, subprocess
import shutil


gi.require_version('Gtk', '3.0')
gi.require_version('Gdk', '3.0')

from os.path import expanduser
from gi.repository import Gdk, Gtk, GdkPixbuf

USER_NAME = utils.get_user()

HOMEDIR = expanduser("~{}".format(USER_NAME))

CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))

CONFIG_FILE = os.path.join(
    HOMEDIR, '.config/slimbookrgbkeyboard/slimbookrgbkeyboard.conf')

AUTOSTART_FILE = os.path.join(
    HOMEDIR, ".config/autostart/slimbookrgbkeyboard-autostart.desktop")


_ = utils.load_translation('slimbookrgb')

# CSS
style_provider = Gtk.CssProvider()
style_provider.load_from_path(CURRENT_PATH+'/style.css')

Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(
), style_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)


class SlimbookRGBKeyboard(Gtk.Window):

    def __init__(self):

        Gtk.Window.__init__(self, title="Slimbook RGB Keyboard")

        self.set_icon_from_file(os.path.join(
            CURRENT_PATH, "images/icono.png"))

        self.set_size_request(900, 400)

        self.set_resizable(False)

        self.set_position(Gtk.WindowPosition.CENTER)

        self.get_style_context().add_class("bg-image")

        win_grid = Gtk.Grid(column_homogeneous=True,
                            row_homogeneous=True,
                            column_spacing=20,
                            row_spacing=0) 

        self.add(win_grid)

        self.load_main_grid(win_grid)

    def load_main_grid(self, win_grid):

        logo_box = Gtk.HBox()
        logo_box.set_hexpand(True)
        logo_box.set_vexpand(True)

        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
            filename=CURRENT_PATH+'/images/logo.png',
            width=400,
            height=100,
            preserve_aspect_ratio=True)

        logo = Gtk.Image.new_from_pixbuf(pixbuf)
        logo.get_style_context().add_class("logo")
        logo.set_halign(Gtk.Align.START)
        logo_box.pack_start(logo, True, True, 0)

        win_grid.attach(logo_box, 0, 0, 7, 1)

        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
            filename=CURRENT_PATH+'/images/icono.png',
            width=200,
            height=200,
            preserve_aspect_ratio=True)

        icon = Gtk.Image.new_from_pixbuf(pixbuf)

        icon.set_halign(Gtk.Align.CENTER)

        win_grid.attach(icon, 5, 1, 2, 5)
        
        self.model = slimbook.info.get_model()
        
        if (self.model & slimbook.info.SLB_MODEL_TITAN) > 0:
            print("Slimbook TITAN detected")
            if (os.path.exists("/usr/bin/ite8291r3-ctl")):
                import ite8291r3_ctl
                win_grid.attach(ite8291r3_ctl.Grid(), 0, 1, 5, 5)
            else:
                import libslimbook_backlight
                win_grid.attach(libslimbook_backlight.Grid(), 0, 1, 5, 5)
            self.check_autostart()
        
        if (self.model == slimbook.info.SLB_MODEL_HERO_RPL_RTX):
            print("Slimbook HERO detected")
            import libslimbook_backlight
            win_grid.attach(libslimbook_backlight.Grid(), 0, 1, 5, 5)

        if (self.model == slimbook.info.SLB_MODEL_CREATIVE_15_A8_RTX):
            print("Slimbook CREATIVE A8 RTX detected")
            import libslimbook_backlight
            win_grid.attach(libslimbook_backlight.Grid(), 0, 1, 5, 5)

        if (self.model == slimbook.info.SLB_MODEL_CREATIVE_15_AI9_RTX5):
            print("Slimbook CREATIVE AI9 RTX detected")
            if (os.path.exists("/usr/bin/ite8291r3-ctl")):
                print("using python3-ite8291r3 backend")
                import ite8291r3_ctl
                win_grid.attach(ite8291r3_ctl.Grid(), 0, 1, 5, 5)
            else:
                import libslimbook_backlight
                win_grid.attach(libslimbook_backlight.Grid(), 0, 1, 5, 5)
            self.check_autostart()
        
        if (self.model & slimbook.info.SLB_MODEL_ESSENTIAL) > 0 or self.model == slimbook.info.SLB_MODEL_HERO_S_TGL_RTX or (self.model & slimbook.info.SLB_MODEL_ELEMENTAL) > 0:
            print("Slimbook Essential/Elemental/Hero-S detected")
            import libslimbook_backlight
            win_grid.attach(libslimbook_backlight.Grid(), 0, 1, 5, 5)
        
        if (self.model & slimbook.info.SLB_MODEL_PROX) > 0:
            print("Slimbook ProX detected")
            print("No backlight support")

    # Info
        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
            filename=CURRENT_PATH+'/images/question.png',
            width=30,
            height=30,
            preserve_aspect_ratio=True)

        iconApp = Gtk.Image.new_from_pixbuf(pixbuf)
        iconApp.get_style_context().add_class("help")
        iconApp.set_halign(Gtk.Align.END)

        lbl_info = Gtk.Label(label="Info  ")

        info_box = Gtk.Box()
        info_box.pack_start(lbl_info, True, True, 0)
        info_box.pack_start(iconApp, True, True, 0)
        info_box.set_name("info")

        evnt_box = Gtk.EventBox(valign=Gtk.Align.END, halign=Gtk.Align.END)
        evnt_box.add(info_box)
        evnt_box.connect("button_press_event", self.about_us)

        win_grid.attach(evnt_box, 6, 5, 1, 1)

    def check_autostart(self):
        if not os.path.isfile(AUTOSTART_FILE):
            autostart_dir = os.path.join(HOMEDIR,'.config/autostart')
            if not os.path.exists(autostart_dir):
                print("Directory doesen't exist")
                os.mkdir(autostart_dir)
            autostart_file = os.path.join(
                CURRENT_PATH, 'slimbookrgbkeyboard-autostart.desktop')
            shutil.copy(autostart_file, AUTOSTART_FILE)

    def about_us(self, widget, x):
        
        if os.getlogin() == 'root':
            os.system('sudo -u {} {}'.format(USER_NAME, os.path.join(CURRENT_PATH, 'slimbookrgbkeyboardinfo.py')))
        else:
            import slimbookrgbkeyboardinfo
            dialog = slimbookrgbkeyboardinfo.PreferencesDialog(self)
            dialog.show_all()


def main():
    win = SlimbookRGBKeyboard()
    win.connect("destroy", Gtk.main_quit)
    win.show_all()
    Gtk.main()

if __name__ == '__main__':
    main()
    



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import os
import gi
import utils

gi.require_version('Gtk', '3.0')
gi.require_version('Gdk', '3.0')

from gi.repository import Gtk, Gdk, GdkPixbuf     
from os.path import expanduser   

# AÑADIR CLASE --> .get_style_context().add_class("button-none")

#IDIOMAS ----------------------------------------------------------------

# pygettext -d slimbookamdcontrollercopy slimbookamdcontrollercopy.py
CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))

_ = utils.load_translation('slimbookrgbkeyboardinfo')


user = expanduser("~")
CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))

style_provider = Gtk.CssProvider()
style_provider.load_from_path(CURRENT_PATH+'/style.css')

Gtk.StyleContext.add_provider_for_screen (
    Gdk.Screen.get_default(), style_provider,
    Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
)

class PreferencesDialog(Gtk.Dialog):
	
    def __init__(self, parent):
		
        super().__init__(
            parent=parent,
			title=_('Information'),
            flags=0)

        self.set_icon_from_file("{}/images/icono.png".format(CURRENT_PATH))
        self.set_position(Gtk.WindowPosition.CENTER_ALWAYS)     
        self.get_style_context().add_class("bg-color")
        self.set_default_size(900, 600)     
        self.set_decorated(False)

        vbox = Gtk.VBox(spacing=5)
        vbox.set_border_width(40)

        self.get_content_area().add(vbox)

        # Icono APP
        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
			filename= CURRENT_PATH+'/images/logo-sb.png',
			width=200,
			height=100,
			preserve_aspect_ratio=True)
        iconApp = Gtk.Image.new_from_pixbuf(pixbuf)
        iconApp.set_name('top')


        info = Gtk.Label()
        info.set_markup("<span>{}</span>".format(
            _('The Slimbook RGB Keyboard app enables full customization of your built-in keyboard backlight color, brightness and visual effects.\n\nThanks to pobrn.')
        ))
        info.set_name('info')
        info.set_line_wrap(True)
        
         # Hya que meter el link de patreon.com/slimbook

        info2 = Gtk.Label()
        info2.set_markup("<span>{}</span>".format(
            _("If you want to support the Slimbook team with the development of this app and several more to come, you can do so by joining our <b><a href='https://patreon.com/slimbook'>patreon</a></b> or buying a brand new Slimbook.")
        ))
        info2.set_name('info')
        info2.set_line_wrap(True)

        enlaces_box = Gtk.Box(spacing=5)
        enlaces_box.set_name('center')
        enlaces_box.set_halign(Gtk.Align.CENTER)

        info3 = Gtk.Label(label=_('This software is provided * as is * without warranty of any kind..'))

        license1 = Gtk.Label()
        license1.set_markup("<span><b>"+_("You are free from:")+"</b></span>")


        license2 = Gtk.Label()
        license2.set_markup("<span><b><small>"+_("Share: ")+"</small></b><small>"+_("copy and redistribute the material in any medium or format\nSlimbook Copyright - License Creative Commons BY-NC-ND")+"</small></span>")


        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
			filename=CURRENT_PATH+'/images/cc.png',
			width=100,
			height=50,
			preserve_aspect_ratio=True)

        licencia = Gtk.Image.new_from_pixbuf(pixbuf)

       

        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
			filename=CURRENT_PATH+'/images/cross.png',
			width=20,
			height=20,
			preserve_aspect_ratio=True)

        close = Gtk.Image.new_from_pixbuf(pixbuf)
        close.set_halign(Gtk.Align.END)

        evnt_close = Gtk.EventBox()
        evnt_close.add(close)
        evnt_close.connect("button_press_event", self.on_button_close)

    # REDES SOCIALES --------------------------------------------------------------
        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
			filename=CURRENT_PATH+'/images/twitter.png',
			width=25,
			height=25,
			preserve_aspect_ratio=True)

        itwitter = Gtk.Image.new_from_pixbuf(pixbuf)
        enlaces_box.pack_start(itwitter, False, False, 0)

        twitter = Gtk.Label()
        twitter.set_markup("<span><b><a href='https://twitter.com/SlimbookEs'>@SlimbookEs</a></b>    </span>")
        twitter.set_justify(Gtk.Justification.CENTER)
        
        enlaces_box.pack_start(twitter, False, False, 0)

        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
			filename=CURRENT_PATH+'/images/facebook.png',
			width=25,
			height=25,
			preserve_aspect_ratio=True)

        ifacebook = Gtk.Image.new_from_pixbuf(pixbuf)
        enlaces_box.pack_start(ifacebook, False, False, 0)

        facebook = Gtk.Label()
        facebook.set_markup("<span><b><a href='https://www.facebook.com/slimbook.es'>Slimbook</a></b>    </span>")
        facebook.set_justify(Gtk.Justification.CENTER)
        enlaces_box.pack_start(facebook, False, False, 0)

        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
			filename=CURRENT_PATH+'/images/insta.png',
			width=25,
			height=25,
			preserve_aspect_ratio=True)

        iinstagram = Gtk.Image.new_from_pixbuf(pixbuf)
        enlaces_box.pack_start(iinstagram, False, False, 0)

        instagram = Gtk.Label()
        instagram.set_markup("<span><b><a href='https://www.instagram.com/slimbookes'>@Slimbook</a></b></span>")
        instagram.set_justify(Gtk.Justification.CENTER)
        enlaces_box.pack_start(instagram, False, False, 0)

    # Enlaces --------------------------------------------------------------------------
        web_link=''
        idiomas = utils.get_languages()[0]
        if idiomas.find('es') >= 0:
            web_link = 'https://slimbook.es/es/'
        else:
            web_link = 'https://slimbook.es/en/'

        box = Gtk.HBox()
        box.set_halign(Gtk.Align.CENTER)
        web = Gtk.Label()
        web.set_markup("<span><b><a href='"+web_link+"'>"+_("@Visit Slimbook web")+"</a></b>    </span>")
        web.set_justify(Gtk.Justification.CENTER)
        box.add(web)

        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
            filename=os.path.join(CURRENT_PATH+ '/images/GitHub_Logo_White.png'),
            width=150,
            height=30,
            preserve_aspect_ratio=True)

        icon = Gtk.Image()
        icon.set_from_pixbuf(pixbuf)
        github = Gtk.LinkButton(uri="https://github.com/slimbook/slimbookrgbkeyboard")
        github.set_name('link')
        github.set_halign(Gtk.Align.CENTER)
        github.set_image(icon)
        box.add(github)

        link = Gtk.LinkButton(uri="https://github.com/slimbook/slimbookrgbkeyboard/tree/main/src/translations",
                              label=(_('Help us with translations!')))
        link.set_name('link')
        link.set_halign(Gtk.Align.CENTER)
        box.add(link)

        #TUTORIAL
        email = Gtk.Label()
        email.set_markup("<span><b>"+_("Send an e-mail to: ")+"dev@slimbook.es</b></span>")
        email.set_justify(Gtk.Justification.CENTER)
        email.set_name('label')
    
    # PACKKING ----------------------------------------------------------------------

        vbox.pack_start(evnt_close,True, True, 0)
        vbox.pack_start(iconApp,True, True,20)

        vbox.pack_start(info,True, True,10)
        vbox.pack_start(info2,True, True,10)
        
        vbox.pack_start(enlaces_box, True, True, 5)
        vbox.pack_start(box, True, True, 10)
        vbox.pack_start(email, True, True, 10)
        vbox.pack_start(info3, True, True, 10)

        vbox.pack_start(license1, True, True, 0)
        vbox.pack_start(license2, True, True, 0)
        vbox.pack_start(licencia, True, True, 10)
        
        #SHOW
        self.show_all()
    
    def on_buttonCopyEmail_clicked(self, buttonCopyEmail):
        self.clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
        self.clipboard.set_text('dev@slimbook.es', -1)
        os.system("notify-send 'Slimbook AMD Controller' "+_("'The email has been copied to the clipboard'") + " -i '" + CURRENT_PATH + "/images/icono.png'")

    def on_button_close(self, button, state):
        self.close()
        self.hide()
        self.destroy()
        Gtk.main_quit()

if __name__ == '__main__':
    win = PreferencesDialog()
    Gtk.main()




from gi.repository import Gdk, Gtk, GdkPixbuf
from os.path import expanduser
import gi
import utils
import os
import subprocess
import re

gi.require_version('Gtk', '3.0')
gi.require_version('Gdk', '3.0')

USER_NAME = utils.get_user()
HOMEDIR = expanduser("~".format(USER_NAME))
CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))
CONFIG_FILE = os.path.join(
    HOMEDIR, '/.config/slimbookrgbkeyboard/slimbookrgbkeyboard.conf')
_ = utils.load_translation('slimbookrgb')
MODULEDIR = "/sys/devices/platform/clevo_platform/"


class Grid(Gtk.Grid):

    def __init__(self, *args, **kwargs):
        kwargs.setdefault('column_homogeneous', True)
        kwargs.setdefault('column_spacing', 0)
        kwargs.setdefault('row_spacing', 20)
        # kwargs.setdefault('halign', Gtk.Align.CENTER)
        # kwargs.setdefault('valign', Gtk.Align.CENTER)
        super(Grid, self).__init__(*args, **kwargs)
        self.check_installation()
        self.setup()

    def setup(self):

        # -- SWITCH --
        self.switch1 = Gtk.Switch()
        if not self.get_value('state')[1] == '0':
            self.switch1.set_active(True)
        print('Switch  loaded: '+str(self.switch1.get_state()))

        self.switch1.set_halign(Gtk.Align.END)
        self.switch1.connect("state-set", self.switch_light)

        # -- SCALE --
        self.scale = Gtk.Scale.new_with_range(
            orientation=Gtk.Orientation.HORIZONTAL,
            min=0,
            max=100,
            step=1
        )
        try:
            value = float(self.get_brightness())/255 * 100
        except:
            value = float(self.get_value("brightness")[1])/255 * 100
        self.scale.set_value(value)
        self.scale.connect("button-release-event", self.set_brightness)
        self.scale.set_sensitive(
            False) if not self.switch1.get_active() else print("Scale active")

    # CONTENT -------------------------------------

        label1 = Gtk.Label(label=_("Light switch"))
        label1.set_halign(Gtk.Align.START)
        label1.set_name('labelw')

        label2 = Gtk.Label(label=_("Brightness"))
        label2.set_halign(Gtk.Align.START)
        label2.set_name('labelw')

        btn_box = Gtk.HBox(spacing=30)

        red_btn = Gtk.Button()
        red_btn.set_name('red')
        red_btn.connect('clicked', self.color_change, '0xff0000')
        btn_box.pack_start(red_btn, True, True, 0)

        green_btn = Gtk.Button()
        green_btn.set_name('green')
        green_btn.connect('clicked', self.color_change, '0x00ff00')
        btn_box.pack_start(green_btn, True, True, 0)

        blue_btn = Gtk.Button()
        blue_btn.set_name('blue')
        blue_btn.connect('clicked', self.color_change, '0x0000ff')
        btn_box.pack_start(blue_btn, True, True, 0)

        white_btn = Gtk.Button()
        white_btn.set_name('white')
        white_btn.connect('clicked', self.color_change, '0xffffff')
        btn_box.pack_start(white_btn, True, True, 0)

        yellow_btn = Gtk.Button()
        yellow_btn.set_name('yellow')
        yellow_btn.connect('clicked', self.color_change, '0xffff00')
        btn_box.pack_start(yellow_btn, True, True, 0)

        magenta_btn = Gtk.Button()
        magenta_btn.set_name('magenta')
        magenta_btn.connect('clicked', self.color_change, '0xff00ff')
        btn_box.pack_start(magenta_btn, True, True, 0)

        colors_lbl = Gtk.Label(label='Colors')
        colors_lbl.set_name('labelw')
        colors_lbl.set_halign(Gtk.Align.START)

    # Grid attach --------------------------------------------------

        self.set_halign(Gtk.Align.CENTER)
        self.attach(label1, 0, 0, 1, 1)
        self.attach(self.switch1, 3, 0, 1, 1)
        self.attach(label2, 0, 1, 1, 1)
        self.attach(self.scale, 2, 1, 2, 1)
        self.attach(colors_lbl, 0, 4, 4, 1)
        self.attach(btn_box, 0, 6, 4, 1)

        self.show_all()

    # Returns a str with param actual_value in .conf
    def get_value(self, parameter):
        exit_code, res = subprocess.getstatusoutput(
            'cat /etc/modprobe.d/clevo_platform.conf')
        if exit_code == 0:
            res = str(res)
            patron = re.compile("{}\=(\w+)".format(parameter)).search(res)
            return patron
        else:
            try:
                file = os.path.join(
                    CURRENT_PATH, "configuration", "clevo_platform.conf")
                exit_code, res = subprocess.getstatusoutput("cat "+file)
                patron = re.compile("{}\=(\w+)".format(parameter)).search(res)
                return patron
            except:
                print("Failed to get clevo_platform.conf")

    def switch_light(self, switch, state):
        if switch.get_active():
            state = 1
            self.scale.set_sensitive(True)
        else:
            state = 0
            self.scale.set_sensitive(False)

        self.apply_and_save(state, "state")

    def color_change(self, widget, color):

        COLORS = {
            "color_left",
            "color_right",
            "color_center"
        }

        for color_zone in COLORS:

            self.apply_and_save(color, color_zone)

    def get_brightness(self):
        exit_code, result = subprocess.getstatusoutput(
            "cat {}{}".format(MODULEDIR, "brightness"))
        return result

    def set_brightness(self, scale, X):

        value = str(scale.get_value())[:-2]

        result = int(255 * int(value) / 100)

        self.apply_and_save(result, "brightness")

    def apply_and_save(self, value, var):
        print("Apply: "+str(value)+" "+str(var))
        group = self.get_value(var).group()
        sudo("echo {} | tee {}{}".format(value, MODULEDIR, var))
        sudo("sed -i 's/{}/{}={}/g' /etc/modprobe.d/clevo_platform.conf".format(group, var, value))

    def check_installation(self):
        # COMPROBATION
        call = subprocess.getstatusoutput(
            'ls /lib/modules/$(uname -r)/build/clevo_platform.ko')

        if call[0] == 0:
            print('Module detected!')
            try:
                self.get_value("last_color")

            except:
                print("Rewriting .conf (adding last_color)")
                # REQUIRES SUDO
                with open('/etc/modprobe.d/clevo_platform.conf', 'a') as file:
                    file.write('\n#last_color=white\n')

        else:
            print('Module is not installed')


def sudo(cmd):
    # print('pkexec slimbookrgbkeyboard-applyconfig-pkexec cmd "{}"'.format(cmd))
    os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec cmd "{}"'.format(cmd))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
import configparser
import logging
import os
import pwd
import shutil
import subprocess
import sys

# We want load first current location
CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))
if CURRENT_PATH not in sys.path:
    sys.path = [CURRENT_PATH] + sys.path

parent_path = os.path.join(CURRENT_PATH,'..')

sys.path.append(parent_path)
import utils

APP_NAME= 'slimbookrgbkeyboard'

USER_NAME = utils.get_user()

HOMEDIR = os.path.expanduser('~{}'.format(USER_NAME))

CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))

DEFAULT_CONF = os.path.join(CURRENT_PATH, '{}.conf'.format(APP_NAME))

CONFIG_FOLDER = os.path.join(HOMEDIR, '.config', APP_NAME)

CONFIG_FILE = os.path.join(CONFIG_FOLDER, '{}.conf'.format(APP_NAME))

uid, gid = pwd.getpwnam(USER_NAME).pw_uid, pwd.getpwnam(USER_NAME).pw_gid

logger = logging.getLogger()


def main():
    logger.info('Checking configuration')
    if not os.path.isdir(CONFIG_FOLDER):
        logger.info('Creating config folder ...')
        os.umask(0)
        os.makedirs(CONFIG_FOLDER, mode=0o766)  # creates with perms
        os.chown(CONFIG_FOLDER, uid, gid)  # set user:group
        logger.info(subprocess.getoutput('ls -la ' + CONFIG_FOLDER))
    else:
        logger.info('Configuration folder ({}) found!'.format(CONFIG_FOLDER))

    config_folder_stat = os.stat(CONFIG_FOLDER)
    logger.debug("uid={} file_uid={}".format(uid, config_folder_stat.st_uid))
    f_uid = config_folder_stat.st_uid
    f_gid = config_folder_stat.st_gid
    
    if not uid == f_uid or not gid == f_gid:
        logger.info('Setting folder ownership')

        for dir_path, dir_name, filenames in os.walk(CONFIG_FOLDER):
            logger.debug(dir_path)
            os.chown(dir_path, uid, gid)
            for filename in filenames:
                file_path = os.path.join(dir_path, filename)
                logger.debug(file_path)
                os.chown(file_path, uid, gid)

    check_config_file()

def check_config_file():
    logger.info("Checking {}'s Configuration".format(APP_NAME.capitalize()))
    if os.path.isfile(CONFIG_FILE):
        config = configparser.ConfigParser()
        config.read(CONFIG_FILE)

        default_config = configparser.ConfigParser()
        default_config.read(DEFAULT_CONF)
        incidences = False

        for section in default_config.sections():
            logger.info('Checking section: {} ...'.format(section))
            if not config.has_section(section):
                incidences = True
                config.add_section(section)
                logger.info('Section added')

            for var in default_config.options(section):
                if not config.has_option(section, var):
                    incidences = True
                    logger.info('Not found: {}'.format(var))
                    config.set(section, var, default_config.get(section, var))

        if incidences:
            try:
                with open(CONFIG_FILE, 'w') as configfile:
                    config.write(configfile)
                logger.info('Incidences corrected.')
            except Exception:
                logger.exception('Incidences could not be corrected.')
        else:
            logger.info('Incidences not found.')

    else:
        logger.info('Creating config file ...')
        shutil.copy(DEFAULT_CONF, CONFIG_FOLDER)
        os.chown(CONFIG_FILE, uid, gid)  # set user:group

if __name__ == '__main__':
    logger.setLevel(logging.DEBUG)
    handler = logging.StreamHandler(sys.stdout)
    handler.setLevel(logging.DEBUG)
    formatter = logging.Formatter('%(asctime)s - %(funcName)s:%(lineno)d - %(levelname)s - %(message)s')
    handler.setFormatter(formatter)
    logger.addHandler(handler)

    logger.info('Config check executed as {}'.format(USER_NAME))
    main()


#!/usr/bin/python3
# -*- coding: utf-8 -*-

import gi
import utils
import os, subprocess
import configparser

gi.require_version('Gtk', '3.0')
gi.require_version('Gdk', '3.0')

from os.path import expanduser
from gi.repository import Gdk, Gtk

USER_NAME = utils.get_user()

HOMEDIR = expanduser("~{}".format(USER_NAME))

CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))

CONFIG_FILE = os.path.join(
    HOMEDIR, '.config/slimbookrgbkeyboard/slimbookrgbkeyboard.conf')

_ = utils.load_translation('slimbookrgb')

# CSS
style_provider = Gtk.CssProvider()
style_provider.load_from_path(CURRENT_PATH+'/style.css')

Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(
), style_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)

class Grid(Gtk.Grid):
    os.system('python3 {}'.format(os.path.join(CURRENT_PATH, 'configuration/check_config.py')))

    config_file = HOMEDIR+'/.config/slimbookrgbkeyboard/slimbookrgbkeyboard.conf'
    config = configparser.ConfigParser()
    config.read(config_file)

    def __init__(self, *args, **kwargs):

        kwargs.setdefault('column_homogeneous', True)
        kwargs.setdefault('column_spacing', 0)
        kwargs.setdefault('row_spacing', 20)
        super(Grid, self).__init__(*args, **kwargs)

        self.setup()

    def setup(self):
        stack = Gtk.Stack()
        stack.set_transition_type(Gtk.StackTransitionType.SLIDE_LEFT_RIGHT)
        stack.set_transition_duration(500)

        stack.add_titled(self.load_kb(), "grid", _("Keyboard"))
        stack.add_titled(self.load_lb(), "grid2", _("Lightbar"))

        # Lightbar settings check
        exit, text = subprocess.getstatusoutput('modprobe qc71_laptop')
        if exit == 0:
            print(' no lightbar')
            
            self.show_all()

        stack_switcher = Gtk.StackSwitcher(valign=Gtk.Align.START)
        stack_switcher.set_stack(stack)

        self.attach(stack_switcher, 0,0,5,1)
        self.attach(stack,0,2,5,4)

    def load_kb(self):
        
        print('\nLoading Keyboard options ...\n')

        # -- SWITCH --
        self.switch = Gtk.Switch()
        if not self.config.get('CONFIGURATION', 'state')=='off':
            self.switch.set_active(True)
        else:
            self.switch.set_active(False)
            
        print('Switch loaded: '+str(self.switch.get_state()))

        self.switch.set_halign(Gtk.Align.END)
        self.switch.connect("state-set", self.kb_switch_light)
        
        # -- SCALE --
        scale = Gtk.Scale.new_with_range(
            orientation=Gtk.Orientation.HORIZONTAL,
            min=0,
            max=50,
            step=1
        )
        value_s = float(self.config.get('CONFIGURATION', 'brightness'))
        print("Scale loaded: "+str(value_s))
        scale.set_value(value=value_s)
        
        scale.connect("button-release-event", self.kb_light_change)
        label_effects = Gtk.Label(label="Effects")
        label_effects.set_name('labelw')
        label_effects.set_halign(Gtk.Align.START)

        btn_folder = Gtk.ToolButton()
        btn_folder.set_icon_name('folder')
        btn_folder.connect('clicked', self.open_anim)
        btn_folder.set_halign(Gtk.Align.START)

        effect_store = Gtk.ListStore(str)
        effects = [
            "breathing",
            "wave",
            "random",
            "rainbow",
            "ripple",
            "marquee",
            "raindrop",
            "aurora",
            "fireworks"
        ]
        for effect in effects:
            effect_store.append([effect])

        animations = subprocess.getoutput("ls "+CURRENT_PATH+"/animations").split("\n")
        print("animations ="+str(animations))

        for animation in animations:
            effect_store.append([animation])

        effects_combo = Gtk.ComboBox.new_with_model(effect_store)
        renderer_text = Gtk.CellRendererText()
        effects_combo.pack_start(renderer_text, True)
        effects_combo.add_attribute(renderer_text, "text", 0)

        # Try to load config last effect on combobox
        try:
            #The last value of 'command' is the effect
            config_effect = self.config.get('CONFIGURATION', 'effect').split(" ")[-1]

            #If last value contains 'animations/' --> It's a route to an anim file so we get just te anim
            if not config_effect.find("animations/")== -1:
                print("Found '/' in config effect, maybe anim")
                config_effect = self.config.get('CONFIGURATION', 'effect').split("/")[-1] #Just Anim name

            
            print("Config_effect: "+config_effect)
            config_effect_index = ""

            for i in range(len(effect_store)):
                model = effects_combo.get_model()
                if model[i][0] == config_effect:
                    config_effect_index = i
                    combo_effect = model[i][0]
                    print("Combo_effect: "+str(combo_effect))

            print("Index: "+str(config_effect_index))

            effects_combo.set_active(config_effect_index)
        except:
            print("Last selection was not an effect")

        effects_combo.connect("changed", self.kb_effect_changed)

        # KB BOTONES

        kb_switch = Gtk.Label(label=_("Light switch"))
        kb_switch.set_halign(Gtk.Align.START)
        kb_switch.set_name('labelw')

        label2 = Gtk.Label(label=_("Brightness"))
        label2.set_halign(Gtk.Align.START)
        label2.set_name('labelw')

        btn_box= Gtk.HBox(spacing=30)
        
        #{black,white,red,green,blue,yellow,aqua,purple,silver,gray,maroon,teal,orange}
           
        white_btn= Gtk.Button()
        white_btn.set_name('white')
        white_btn.connect('clicked', self.kb_color_change, 'white', effects_combo)
        btn_box.pack_start(white_btn, True, True, 0)

        aqua_btn= Gtk.Button()
        aqua_btn.set_name('aqua')
        aqua_btn.connect('clicked', self.kb_color_change, 'aqua', effects_combo)
        btn_box.pack_start(aqua_btn, True, True, 0)

        teal_btn= Gtk.Button()
        teal_btn.set_name('teal')
        teal_btn.connect('clicked', self.kb_color_change, 'teal', effects_combo)
        btn_box.pack_start(teal_btn, True, True, 0)

        blue_btn= Gtk.Button()
        blue_btn.set_name('blue')
        blue_btn.connect('clicked', self.kb_color_change, 'blue', effects_combo)
        btn_box.pack_start(blue_btn, True, True, 0)

        purple_btn= Gtk.Button()
        purple_btn.set_name('purple')
        purple_btn.connect('clicked', self.kb_color_change, 'purple', effects_combo)
        btn_box.pack_start(purple_btn, True, True, 0)

        red_btn= Gtk.Button()
        red_btn.set_name('red')
        red_btn.connect('clicked', self.kb_color_change,'red', effects_combo)
        btn_box.pack_start(red_btn, True, True, 0)

        orange_btn= Gtk.Button()
        orange_btn.set_name('orange')
        orange_btn.connect('clicked', self.kb_color_change, 'orange', effects_combo)
        btn_box.pack_start(orange_btn, True, True, 0)

        yellow_btn= Gtk.Button()
        yellow_btn.set_name('yellow')
        yellow_btn.connect('clicked', self.kb_color_change, 'yellow', effects_combo)
        btn_box.pack_start(yellow_btn, True, True, 0)

        green_btn= Gtk.Button()
        green_btn.set_name('green')
        green_btn.connect('clicked', self.kb_color_change, 'green', effects_combo)
        btn_box.pack_start(green_btn, True, True, 0)

        colors_lbl = Gtk.Label(label='Colors')
        colors_lbl.set_name('labelw')
        colors_lbl.set_halign(Gtk.Align.START)
        
    # Grid attach KB --------------------------------------------------
        kb_grid = Gtk.Grid(column_homogeneous=True,
                            row_homogeneous=False,
                            column_spacing=10,
                            row_spacing=20)

        kb_grid.attach(kb_switch, 0, 0, 2, 1)
        kb_grid.attach(self.switch, 2, 0, 2, 1)
        kb_grid.attach(label2, 0, 1, 2, 1)
        kb_grid.attach(scale, 2, 1, 2, 1)

        kb_grid.attach(colors_lbl, 0, 3, 5, 1)
        kb_grid.attach(btn_box, 0, 4, 6, 1)

        kb_grid.attach(label_effects, 0, 6, 5, 1)
        kb_grid.attach(effects_combo, 0, 7, 5, 1)
        kb_grid.attach(btn_folder, 5, 7, 1, 1)

        return kb_grid

    def load_lb(self):

        print('\nLoading Lightbar options ...\n')


        # -- LIGHTBAR SWITCH --
        self.lb_switch = Gtk.Switch()
        if not self.config.get('CONFIGURATION', 'lb_state')=='0':
            self.lb_switch.set_active(True)
        else:
            self.lb_switch.set_active(False)
            
        print('Switch  loaded: '+str(self.lb_switch.get_state()))

        self.lb_switch.set_halign(Gtk.Align.END)
        self.lb_switch.connect("state-set", self.lb_switch_light)

        # -- LIGHTBAR SWITCH --
        self.lb_rainbow_switch = Gtk.Switch()                 
        if not self.config.get('CONFIGURATION', 'lb_rainbow')=='0':
            self.lb_rainbow_switch.set_active(True)
        else:
            self.lb_rainbow_switch.set_active(False)
            
        print('Switch  loaded: '+str(self.lb_rainbow_switch.get_state()))

        self.lb_rainbow_switch.set_halign(Gtk.Align.END)
        self.lb_rainbow_switch.connect("state-set", self._lb_rainbow_switch)

        # LABELS
        lb_switch = Gtk.Label(label="Light switch")
        lb_switch.set_name('labelw')
        lb_switch.set_halign(Gtk.Align.START)

        label_rainbow = Gtk.Label(label="Rainbow mode")
        label_rainbow.set_name('labelw')
        label_rainbow.set_halign(Gtk.Align.START)

        lb_btn_box= Gtk.HBox(spacing=30)
        #{black,white,red,green,blue,yellow,aqua,purple,silver,gray,maroon,teal,orange}

        white_btn= Gtk.Button()
        white_btn.set_name('white')
        white_btn.connect('clicked', self.lb_color_change, '999')
        lb_btn_box.pack_start(white_btn, True, True, 0)

        aqua_btn= Gtk.Button()
        aqua_btn.set_name('aqua')
        aqua_btn.connect('clicked', self.lb_color_change, '799')
        lb_btn_box.pack_start(aqua_btn, True, True, 0)

        teal_btn= Gtk.Button()
        teal_btn.set_name('teal')
        teal_btn.connect('clicked', self.lb_color_change, '688')
        lb_btn_box.pack_start(teal_btn, True, True, 0)

        blue_btn= Gtk.Button()
        blue_btn.set_name('blue')
        blue_btn.connect('clicked', self.lb_color_change, '009')
        lb_btn_box.pack_start(blue_btn, True, True, 0)

        purple_btn= Gtk.Button()
        purple_btn.set_name('purple')
        purple_btn.connect('clicked', self.lb_color_change, '909')
        lb_btn_box.pack_start(purple_btn, True, True, 0)

        red_btn= Gtk.Button()
        red_btn.set_name('red')
        red_btn.connect('clicked', self.lb_color_change,'900')
        lb_btn_box.pack_start(red_btn, True, True, 0)

        orange_btn= Gtk.Button()
        orange_btn.set_name('orange')
        orange_btn.connect('clicked', self.lb_color_change, '940')
        lb_btn_box.pack_start(orange_btn, True, True, 0)

        yellow_btn= Gtk.Button()
        yellow_btn.set_name('yellow')
        yellow_btn.connect('clicked', self.lb_color_change, '990')
        lb_btn_box.pack_start(yellow_btn, True, True, 0)

        green_btn= Gtk.Button()
        green_btn.set_name('green')
        green_btn.connect('clicked', self.lb_color_change, '090')
        lb_btn_box.pack_start(green_btn, True, True, 0)

        lb_colors_lbl = Gtk.Label(label='Ligtbar Colors')
        lb_colors_lbl.set_name('labelw')
        lb_colors_lbl.set_halign(Gtk.Align.START)

    # GRID ATTACH

        lb_grid = Gtk.Grid(column_homogeneous=True,
                    row_homogeneous=False,
                    column_spacing=10,
                    row_spacing=25)

        lb_grid.attach(lb_switch, 0, 0, 1, 1)
        lb_grid.attach(self.lb_switch, 1, 0, 2, 1)
        lb_grid.attach(label_rainbow, 0, 2, 1, 1)
        lb_grid.attach(self.lb_rainbow_switch, 1, 2, 2, 1)
        lb_grid.attach(Gtk.Separator(), 0, 4, 5, 1)
        lb_grid.attach(lb_colors_lbl, 0, 4, 5, 1)
        lb_grid.attach(lb_btn_box, 0, 6, 5, 1)

        return lb_grid


    def kb_effect_changed(self, combo):

        config = configparser.ConfigParser()
        config.read(self.config_file)
        tree_iter = combo.get_active_iter()

        if tree_iter is not None:
            model = combo.get_model()
            effect = model[tree_iter][0].lower()
            print("\nSelected: effect = %s" % effect)


            call = subprocess.getstatusoutput("ls "+CURRENT_PATH+"/animations/ | grep "+effect)
            #print(str(call))

            if not (call[0]==0): #If not in animations --> effect

            #Chek if it's an effect or an animation
                command = "sudo ite8291r3-ctl effect "+effect
                self.update_config_field("effect",command)
                call = subprocess.getstatusoutput('pkexec slimbookrgbkeyboard-applyconfig-pkexec effect')

                if not call[0]==0: #This means there's no error message
                    raise ValueError("Can't execute as effect." )
                print("\nEffect applied") 

            else:
                print("\nI's not an effect going to apply as anim")
                command = "sudo ite8291r3-ctl anim --file "+CURRENT_PATH+"/animations/"+effect
                self.update_config_field("effect",command)
                os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec effect')
                print("\nAnim applied")
            
            os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec brightness')
                   
    def kb_switch_light(self, switch, state):     
        config = configparser.ConfigParser()
        config.read(self.config_file)
        

        if switch.get_active() == True:
            #Switch on load effect
            effect = config.get('CONFIGURATION', 'effect')
            self.update_config_field("state","on")
            os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec state')
        else:      
            self.update_config_field("state","off")    
            os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec state')

    def kb_color_change(self, widget, color, effects_combo):
        print(widget)

        if color[0:2].isnumeric():
            
            command = "sudo ite8291r3-ctl monocolor --rgb "+color
            self.update_config_field("effect",command) 
            effects_combo.set_active_iter(None)
            if self.switch.get_state():
                os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec effect') 
            else:
                self.switch.set_active(True)
            
        else:
            # If new_color is not black, we save it as a backup for switch on
            
            command = "sudo ite8291r3-ctl monocolor --name "+color
            self.update_config_field("effect",command)  
            effects_combo.set_active_iter(None)
            if self.switch.get_state():
                os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec effect') 
            else:
                self.switch.set_active(True)

    def kb_light_change(self, scale, value):

        #Existent value

        new_value = str(scale.get_value())[:-2]
        self.update_config_field("brightness", new_value)
        os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec brightness')


    def lb_switch_light(self, switch, state):     
        config = configparser.ConfigParser()
        config.read(self.config_file)
        
        if switch.get_active() == True:
            #Switch on load effect
            self.update_config_field("lb_state","1")
            os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec lb_state')
        else:      
            self.update_config_field("lb_state","0")    
            os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec lb_state')

    def _lb_rainbow_switch(self, switch, state):     
        config = configparser.ConfigParser()
        config.read(self.config_file)
        
        if switch.get_active() == True:
            #Switch on load effect
            self.update_config_field("lb_rainbow","1")
            os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec lb_rainbow')
        else:      
            self.update_config_field("lb_rainbow","0")    
            os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec lb_rainbow')
            
    def lb_color_change(self, widget, color):

        self.lb_switch.set_active(True)
        if self.lb_rainbow_switch.get_state():
            print('Rainbow deactivation')
            self.lb_rainbow_switch.set_active(False)
        self.update_config_field("lb_color", color)
        os.system('pkexec slimbookrgbkeyboard-applyconfig-pkexec lb_color')    

    
    def open_anim(self, button):
        os.system('xdg-open '+CURRENT_PATH+'/animations')

    def update_config_field(self, variable, value):
        
        fichero = HOMEDIR + '/.config/slimbookrgbkeyboard/slimbookrgbkeyboard.conf'
        config = configparser.ConfigParser()
        config.read(fichero)
        
        # We change our variable: config.set(section, variable, value)
        config.set('CONFIGURATION', str(variable), str(value))

        # Writing our configuration file 
        with open(fichero, 'w') as configfile:
            config.write(configfile)
